/**
 * \file
 * <!--
 * This file is part of BeRTOS.
 *
 * Bertos is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * As a special exception, you may use this file as part of a free software
 * library without restriction.  Specifically, if other files instantiate
 * templates or use macros or inline functions from this file, or you compile
 * this file and link it with other files to produce an executable, this
 * file does not by itself cause the resulting executable to be covered by
 * the GNU General Public License.  This exception does not however
 * invalidate any other reasons why the executable file might be covered by
 * the GNU General Public License.
 *
 * Copyright 2010 Develer S.r.l. (http://www.develer.com/)
 *
 * -->
 *
 * \brief Generic utilities.
 * \author Giovanni Bajo <rasky@develer.com>
 *
 */

#include "util.h"
#include <sec/kdf/pbkdf2.h>
#include <sec/mac/hmac.h>
#include <sec/hash/sha1.h>

// FIXME: this macros should be generated by the wizard
#define BERTOS_PROJECT_NAME   "bertos_project"

#define SALT   (BERTOS_PROJECT_NAME "P2K_SALT")

void password2key(const char *pwd, size_t pwd_len,
				  uint8_t *key, size_t key_len)
{
	Kdf *kdf = PBKDF2_stackinit(hmac_stackinit(SHA1_stackinit()));

	kdf_begin(kdf, pwd, pwd_len, (uint8_t*)SALT, sizeof(SALT));
	kdf_read(kdf, key, key_len);

	// FIXME: how to purge the stack?
}
